package org.xtext.naming;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.naming.QualifiedName;
import org.eclipse.xtext.naming.SimpleNameProvider;

import reusablecomponents.Component;
import reusablecomponents.ComponentDef;
import reusablecomponents.Port;
import reusablecomponents.PortDef;

/*
 * Extensin de la implementacin que aporta Xtext del proveedor de nombres, 
 * cuya funcionalidad es indicar el identificador que se ha de utilizar para 
 * hacer referencia a un elemento del modelo
 */
public class ReusableComponentsIQualifiedNameProvider extends SimpleNameProvider {

	/*
	 * El mtodo getFullyQualifiedName, toma como entrada un EObject y devuelve
	 * un QualifiedName, en el caso de que obj sea de tipo Port o PortDef, la
	 * salida estara formada por la concatenacin del nombre del componente 
	 * que contiene este elemento, un punto y el nombre del propio puerto. As,
	 * cuando un usuario pretende realizar una conexin entre dos puertos existentes
	 * y escribe en el modelo el nombre de uno de ellos, el framework es capaz de 
	 * saber el objeto Port al que el usuario se refiere ya que puede invocar, con 
	 * cada uno de los objetos Port existentes en el modelo, el mtodo 
	 * getFullyQualifiedName y encontrar aquel cuya salida corresponda con 
	 * lo que el usuario ha escrito. 
	 */
	@Override
	public QualifiedName getFullyQualifiedName(EObject obj) {
		
		String portName;
		String componentName;
		QualifiedName result = null;

		if (obj instanceof Port) {
			portName = ((Port) obj).getName();
			componentName = ((Component)obj.eContainer()).getName();
			if(componentName != null && portName != null
					&& !componentName.isEmpty() && !portName.isEmpty())
				result = QualifiedName.create(componentName, portName);
		}
		else if(obj instanceof PortDef) {
			portName = ((PortDef) obj).getName();
			componentName = ((ComponentDef)obj.eContainer()).getName();
			if(componentName != null && portName != null
					&& !componentName.isEmpty() && !portName.isEmpty())
				result = QualifiedName.create(componentName, portName);
		}
		else if(obj instanceof Component) {
			componentName = ((Component) obj).getName();
			
			if(componentName != null && !componentName.isEmpty())
				result = super.getFullyQualifiedName(obj);
		}
		else if(obj instanceof ComponentDef) {
			componentName = ((ComponentDef) obj).getName();
			
			if(componentName != null && !componentName.isEmpty())
				result = super.getFullyQualifiedName(obj);
		}
		else {
			result = super.getFullyQualifiedName(obj);
		}
		return result;
	}
}
